package com.br.vini.compose.api

import androidx.datastore.preferences.protobuf.Api
import com.br.fechadura.mobile.api.model.Usuario
import com.br.fechadura.mobile.api.request.LoginRequestBody
import com.br.fechadura.mobile.api.request.UsuarioRequestBody
import com.br.fechadura.mobile.api.response.GrupoPortaResponseBody
import com.br.fechadura.mobile.api.response.GrupoPortasResponseBody
import com.br.fechadura.mobile.api.response.GrupoUsuarioResponseBody
import com.br.fechadura.mobile.api.response.GrupoUsuariosResponseBody
import com.br.fechadura.mobile.api.response.LoginResponseBody
import com.br.fechadura.mobile.api.response.PortaResponseBody
import com.br.fechadura.mobile.api.response.PortasResponseBody
import com.br.fechadura.mobile.api.response.UsuarioPostResponseBody
import com.br.fechadura.mobile.api.response.UsuarioResponseBody
import com.br.fechadura.mobile.api.response.UsuariosResponseBody

/*
Classe que contém os métodos de chamada à API.
Os métodos serão executados dentro do ViewModel.
Cada método retorna o estado da api representado pelo objeto ApiState.
 */
class ApiRepository: BaseRepository() {
    suspend fun login(requestBody: LoginRequestBody) : ApiState<LoginResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.login(requestBody) }
    }

    // Usuários
    suspend fun getUsuarios() : ApiState<UsuariosResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.usuarios() }
    }

    suspend fun getAllUsuarios() : ApiState<UsuariosResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.getAllUsuarios() }
    }

    suspend fun postUsuario(requestBody: UsuarioRequestBody) : ApiState<UsuarioPostResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.postUsuario(requestBody) }
    }

    suspend fun getUsuarioById(id: String): ApiState<UsuarioResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.getUsuariosById(id) }
    }

    // Grupo de Usuários
    suspend fun getGrupoUsuarios(): ApiState<GrupoUsuariosResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.getGrupoUsuarios() }
    }

    suspend fun getGrupoUsuarioById(id: String) : ApiState<GrupoUsuarioResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.getGrupoUsuarioById(id) }
    }

    // Portas
    suspend fun getPortas() : ApiState<PortasResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.getPortas() }
    }


    suspend fun getPortaById(id: String) : ApiState<PortaResponseBody> {
        return  makeApiCall { ApiClient.apiEndpoint.getPortaById(id) }
    }

    // Grupo de Portas
    suspend fun getGrupoPortas() : ApiState<GrupoPortasResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.getGrupoPortas() }
    }

    suspend fun getGrupoPortaById(id: String) : ApiState<GrupoPortaResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.getGrupoPortaById(id) }
    }

    /*====================================Usado para fazer POST nas demais telas==============================================*/

//    // Todos os usuários
//    suspend fun getAllUsuarios() : ApiState<UsuariosResponseBody> {
//        return makeApiCall { ApiClient.apiEndpoint.getAllUsuarios() }
//    }

    // Todos as portas
    suspend fun getAllPortas() : ApiState<PortasResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.getAllPortas() }
    }

    // Todos os grupos de usuários
    suspend fun getAllGrupoUsuarios() : ApiState<GrupoUsuariosResponseBody> {
        return makeApiCall { ApiClient.apiEndpoint.getAllGrupoUsuarios() }
    }

//    // Todos os usuários
//    suspend fun getlAllGrupoPortas() : ApiState<GrupoPortasResponseBody> {
//        return makeApiCall { ApiClient.apiEndpoint.getAllGrupoPortas() }
//    }
}