package com.br.fechadura.mobile.ui.components

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.NavigationBarItemColors
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.br.fechadura.mobile.R

@Composable
fun BottomAppBar(
    navController: NavController,
) {
    val items = remember {
        listOf(
            BottomBarItem("Usuários", R.drawable.usuario, "usuario"),
            BottomBarItem("Grupo Usuários", R.drawable.grupousuario, "grupo-usuario"),
            BottomBarItem("Portas", R.drawable.portaa, "porta"),
            BottomBarItem("Grupos Portas", R.drawable.grupoporta, "grupo-porta")
        )
    }
    var selectedRoute by remember {
        mutableStateOf(items.first().route)
    }

    Row(
        horizontalArrangement = Arrangement.SpaceBetween,
        modifier = Modifier
            .fillMaxWidth()
            .height(80.dp),
        verticalAlignment = Alignment.CenterVertically,
    ) {
        items.forEach { item ->
            NavigationBarItem(
                selected = selectedRoute == item.route,
                onClick = {
                    selectedRoute = item.route
                    navController.navigate(item.route)
                },
                icon = {
                    Icon(
                        painter = painterResource(id = item.icon),
                        contentDescription = null,
                        modifier = Modifier
                            .width(30.dp)
                            .height(30.dp)
                    )
                }
            )
        }
    }
}
data class BottomBarItem(val label: String, val icon: Int, val route: String)
@Preview(showSystemUi = true)
@Composable
private fun BottomAppBarPreview() {
    BottomAppBar(navController = rememberNavController())
}