package com.br.fechadura.mobile.ui.components

import CadastrarGrupoUsuario
import androidx.compose.foundation.ExperimentalFoundationApi
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.width
import androidx.compose.material3.BottomAppBar
import androidx.compose.material3.Icon
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.NavigationBarItemColors
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.remember
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import androidx.navigation.navOptions
import com.br.fechadura.mobile.R
import com.br.fechadura.mobile.ui.screens.CarregamentoScreen
import com.br.fechadura.mobile.ui.screens.InicioScreen
import com.br.fechadura.mobile.ui.screens.PerfilScreen
import com.br.fechadura.mobile.ui.screens.grupoPortas.CadastrarGrupoPorta
import com.br.fechadura.mobile.ui.screens.grupoPortas.EditarGrupoPorta
import com.br.fechadura.mobile.ui.screens.grupoUsuarios.GrupoUsuarioScreen
import com.br.fechadura.mobile.ui.screens.login.LoginScreen
import com.br.fechadura.mobile.ui.screens.portas.CadastrarPorta
import com.br.fechadura.mobile.ui.screens.portas.EditarPorta
import com.br.fechadura.mobile.ui.screens.usuario.CadastrarUsuario
import com.br.fechadura.mobile.ui.screens.usuario.EditarUsuario
import com.br.fechadura.mobile.ui.screens.portas.PortaScreen
import com.br.fechadura.mobile.ui.screens.grupoPortas.GrupoPortaScreen
import com.br.fechadura.mobile.ui.screens.grupoPortas.VisualizarGrupoPorta
import com.br.fechadura.mobile.ui.screens.grupoUsuarios.EditarGrupoUsuario
import com.br.fechadura.mobile.ui.screens.usuario.UsuarioScreen
import com.br.fechadura.mobile.ui.screens.usuario.VisualizarGrupoUsuario
import com.br.fechadura.mobile.ui.screens.usuario.VisualizarUsuario
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.fechadura.mobile.ui.theme.FundoFechaduraColor
import com.google.accompanist.pager.ExperimentalPagerApi

@OptIn(ExperimentalPagerApi::class, ExperimentalFoundationApi::class, ExperimentalPagerApi::class)
@Composable
fun BottomBarNavigation() {
    val navController = rememberNavController()
    var showBottomBar by remember { mutableStateOf(true) }
    var selectedRoute by remember { mutableStateOf("inicio") }

    LaunchedEffect(navController) {
        navController.addOnDestinationChangedListener { _, destination, _ ->
            showBottomBar =
                destination.route != "login" &&
                destination.route != "carregamento" &&
                destination.route != "visualizar-porta/{id}" &&
                destination.route != "visualizar-usuario/{id}"
        }
    }

    val items = listOf(
        BottomBarItem("Usuários", R.drawable.usuario, "usuario"),
        BottomBarItem("Grupo Usuários", R.drawable.grupousuario, "grupo-usuario"),
        BottomBarItem("Inicio", R.drawable.home, "inicio"),
        BottomBarItem("Portas", R.drawable.portaa, "porta"),
        BottomBarItem("Grupos Portas", R.drawable.grupoporta, "grupo-porta")
    )

    Column(Modifier.fillMaxSize()) {
        NavHost(
            navController = navController,
            startDestination = "carregamento",
            Modifier.weight(1f)
        ) {
            composable("carregamento") {
                CarregamentoScreen(navController)
            }
            composable("login") {
                LoginScreen(navController)
            }
            composable("inicio") {
                InicioScreen(navController)
            }
            composable("perfil") {
                PerfilScreen(navController)
            }
            composable("usuario") {
                UsuarioScreen(navController)
            }
            composable("cadastrar-usuario") {
                CadastrarUsuario(navController)
            }
            composable("visualizar-usuario/{id}") { backStackEntry ->
                val aId = backStackEntry.arguments?.getString("id")
                aId?.let { id ->
                    VisualizarUsuario(id, navController)
                }
            }
            composable("editar-usuario/{id}") { backStackEntry ->
                val aId = backStackEntry.arguments?.getString("id")
                aId?.let { id ->
                    EditarUsuario(id, navController)
                }
            }
            composable("porta") {
                PortaScreen(navController)
            }
            composable("cadastrar-porta") {
                CadastrarPorta(navController)
            }
            composable("editar-porta/{id}") { backStackEntry ->
                val aId = backStackEntry.arguments?.getString("id")
                aId?.let { id ->
                    EditarPorta(id, navController)
                }

            }

            composable("grupo-porta") {
                GrupoPortaScreen(navController)
            }
            composable("cadastrar-grupo-porta") {
                CadastrarGrupoPorta(navController)
            }
            composable("visualizar-grupo-porta/{id}") { backStackEntry ->
                val aId = backStackEntry.arguments?.getString("id")
                aId?.let { id ->
                    VisualizarGrupoPorta(navController, id)
                }
            }
            composable("editar-grupo-porta/{id}") { backStackEntry ->
                val aId = backStackEntry.arguments?.getString("id")
                aId?.let { id ->
                    EditarGrupoPorta(navController, id)
                }
            }
            composable("grupo-usuario") {
                GrupoUsuarioScreen(navController)
            }
            composable("cadastrar-grupo-usuario") {
                CadastrarGrupoUsuario(navController)
            }
            composable("visualizar-grupo-usuario/{id}") { backStackEntry ->
                val aId = backStackEntry.arguments?.getString("id")
                aId?.let { id ->
                    VisualizarGrupoUsuario(id, navController)
                }
            }
            composable("editar-grupo-usuario/{id}") { backStackEntry ->
                val aId = backStackEntry.arguments?.getString("id")
                aId?.let { id ->
                    EditarGrupoUsuario(id, navController)
                }
            }
        }

        if (showBottomBar) {
            BottomAppBar(
                actions = {
                    items.forEach { item ->
                        NavigationBarItem(
                            selected = selectedRoute == item.route,
                            onClick = {
                                selectedRoute = item.route
                                navController.navigate(item.route, navOptions = navOptions {
                                    launchSingleTop = true
                                    popUpTo(navController.graph.startDestinationId)
                                })
                            },
                            colors = NavigationBarItemColors(
                                selectedIconColor = FechaduraColor,
                                unselectedIconColor = Color.Black,
                                selectedTextColor = Color.Black,
                                unselectedTextColor = Color.Black,
                                disabledIconColor = Color.Black.copy(alpha = 0.4f),
                                disabledTextColor = Color.Black.copy(alpha = 0.4f),
                                selectedIndicatorColor = FundoFechaduraColor
                            ),
                            icon = {
                                val iconSize: Dp = when (item.route) {
                                    "inicio" -> 42.dp
                                    else -> 32.dp
                                }
                                Icon(
                                    painter = painterResource(id = item.icon),
                                    contentDescription = null,
                                    modifier = Modifier
                                        .width(iconSize)
                                        .height(iconSize)
                                )
                            }
                        )
                    }
                },
                containerColor = Color.White
            )
        }
    }
}
