package com.br.fechadura.mobile.ui.components


import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.CheckCircle
import androidx.compose.material3.AlertDialog
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.vector.ImageVector
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.br.fechadura.mobile.ui.theme.FechaduraColor

@Composable
fun CaixaDialogo(
    onDismissRequest: () -> Unit,
    onConfirmation: () -> Unit,
    dialogTitle: String,
    dialogText: String,
    icon: ImageVector,
) {
    Box (
        modifier = Modifier.fillMaxSize(),
        contentAlignment = Alignment.Center
    ){
        AlertDialog(
            onDismissRequest = {
                onDismissRequest()
            },
            icon = {
                Icon(
                    icon,
                    contentDescription = "Check Circle",
                    tint = FechaduraColor,
                    modifier = Modifier.size(32.dp)
                )
            },
            title = {
                Text(
                    text = dialogTitle,
                    color = Color.Black,
                    textAlign = TextAlign.Center,
                    fontSize = 19.sp
                )
            },
            text = {
                Text(
                    text = dialogText,
                    color = Color.Black,
                    textAlign = TextAlign.Center,
                    modifier = Modifier.fillMaxWidth(),
                    fontSize = 15.sp
                )
            },
            confirmButton = {
                Row {
                    Button(
                        onClick = { onConfirmation()},
                        colors = ButtonDefaults.buttonColors(
                            containerColor = FechaduraColor
                        ),
                        modifier = Modifier
                            //.fillMaxWidth()
                            .weight(1f)
                            .padding(5.dp, 5.dp)
                            .height(45.dp)
                    ) {
                        Text(
                            text = "Ok",
                            modifier = Modifier,
                            fontSize = 16.sp,
                            fontWeight = FontWeight.Bold
                        )
                    }
                }
            }
        )
    }

}

@Preview
@Composable
private fun Preview() {
 CaixaDialogo(
     onDismissRequest = { /*TODO*/ },
     onConfirmation = { /*TODO*/ },
     dialogTitle = "Cadastro de Usuário",
     dialogText = "Cadastro realizado com sucesso.",
     icon =  Icons.Default.CheckCircle
 )
}