package com.br.fechadura.mobile.ui.components

import androidx.compose.foundation.layout.*
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.AccountCircle
import androidx.compose.material.icons.filled.Search
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.br.fechadura.mobile.ui.theme.Branco
import com.br.fechadura.mobile.ui.theme.FechaduraColor

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun TopAppBar(
    navController: NavController,
    showBackButton: Boolean = false,
    showSearchIcon: Boolean = false,
    showAccountIcon: Boolean = true,
    title: String = "",
    modifier: Modifier = Modifier,
    searchText: String?,
    onSearchChange: ((String) -> Unit)? = null
) {
    var isSearchActive by remember { mutableStateOf(false) }

    TopAppBar(
        title = {
            if (showSearchIcon) {
                if (isSearchActive) {
                    TextField(
                        value = searchText ?: "",
                        onValueChange = { newValue ->
                            if (onSearchChange != null) {
                                onSearchChange(newValue)
                            }
                        },
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(end = 8.dp),
                        leadingIcon = {
                            Icon(Icons.Default.Search, contentDescription = "Pesquisar", tint = Branco)
                        },
                        label = { Text(text = "Pesquise aqui", color = Branco) },
                        placeholder = { Text("Quem procura?", color = Branco) },
                        singleLine = true,
                        colors = TextFieldDefaults.textFieldColors(
                            containerColor = Color.Transparent,
                            cursorColor = Color.Black,
                            focusedIndicatorColor = Color.Black,
                            unfocusedIndicatorColor = Color.Black,
                            disabledIndicatorColor = Color.Black
                        )
                    )
                } else {
                    Text(title, color = Color.White)
                }
            } else {
                Text(title, color = Color.White)
            }
        },
        colors = TopAppBarDefaults.topAppBarColors(
            containerColor = FechaduraColor
        ),
        navigationIcon = {
            if (showBackButton) {
                IconButton(onClick = { navController.navigateUp() })
                {
                    Icon(
                        imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                        contentDescription = "Voltar",
                        tint = Branco
                    )
                }
            }
        },
        actions = {
            if (showSearchIcon) {
                IconButton(onClick = { isSearchActive = !isSearchActive }) {
                    Icon(
                        imageVector = Icons.Default.Search,
                        contentDescription = if (isSearchActive) "Fechar pesquisa" else "Abrir pesquisa",
                        tint = Branco
                    )
                }
            }
            if(showAccountIcon) {
                IconButton(onClick = { navController.navigate("perfil") }) {
                    Icon(Icons.Default.AccountCircle, contentDescription = "Meu perfil", tint = Branco)
                }
            }
        },
        modifier = modifier
    )
}

@Preview(showSystemUi = true)
@Composable
private fun TopAppBarPreview() {
    var searchText by remember { mutableStateOf("") }
    TopAppBar(
        navController = rememberNavController(),
        title = "Título da App Bar",
        searchText = searchText,
        onSearchChange = { searchText = it },
        showBackButton = true,
        showSearchIcon = true // Teste com `true` e `false` para verificar o comportamento
    )
}
