package com.br.fechadura.mobile.ui.screens.grupoPortas

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.LazyRow
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.Divider
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.Check
import androidx.compose.material.icons.filled.Close
import androidx.compose.material.icons.filled.Person
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.semantics.Role
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.br.fechadura.mobile.api.model.GrupoPorta
import com.br.fechadura.mobile.sampledata.sampleDataDoors
import com.br.fechadura.mobile.sampledata.sampleDataGroupDoors
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.fechadura.mobile.ui.theme.onPrimaryLight
import com.br.fechadura.mobile.ui.theme.outlineLight
import com.br.fechadura.mobile.ui.theme.primaryContainerLight
import com.br.fechadura.mobile.ui.theme.primaryLight
import com.br.fechadura.mobile.ui.theme.secondaryLight
import kotlinx.coroutines.launch

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun CadastrarGrupoPorta(
    navController: NavController,
) {

    var nome by remember { mutableStateOf("") }
    var descricao by remember { mutableStateOf("") }
    var ativo by remember { mutableStateOf(false) }

    var selectedPortas by remember { mutableStateOf(setOf<String>()) }
    var selectedText by remember { mutableStateOf("Selecione as portas") }
    var searchQuery by remember { mutableStateOf("") }

    val sampleDataPortas = sampleDataDoors // Lista completa de portas
    val sheetState = rememberModalBottomSheetState()
    val scope = rememberCoroutineScope()
    var showBottomSheet by remember { mutableStateOf(false) }

    Scaffold(
        topBar = {
            TopAppBar(
                title = {
                    Text(nome.takeIf { it.isNotEmpty() } ?: "Cadastrar grupo")
                },
                navigationIcon = {
                    IconButton(onClick = { navController.popBackStack() }) {
                        Icon(
                            imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                            contentDescription = "Voltar",
                            tint = Color.White
                        )
                    }
                },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = FechaduraColor,
                    actionIconContentColor = Color.Gray,
                    navigationIconContentColor = Color.Gray,
                    scrolledContainerColor = Color.Gray,
                    titleContentColor = Color.White
                )
            )
        },
    ) { innerPadding ->
        Box(
            modifier = Modifier
                .fillMaxSize()
                .background(Color.White)
                .padding(innerPadding)
        ) {

            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(20.dp),
                verticalArrangement = Arrangement.SpaceBetween
            ) {
                Column(
                    verticalArrangement = Arrangement.spacedBy(14.dp, Alignment.CenterVertically)
                ) {

                    OutlinedTextField(
                        value = nome,
                        onValueChange = { nome = it },
                        label = {
                            Text(
                                "Nome",
                                color = FechaduraColor,
                                fontSize = 13.sp
                            )
                        },
                        modifier = Modifier
                            .fillMaxWidth(),
                        textStyle = TextStyle(color = Color.Black),
                        singleLine = true
                    )

                    OutlinedTextField(
                        value = descricao,
                        onValueChange = { descricao = it },
                        label = {
                            Text(
                                "Descrição",
                                color = FechaduraColor,
                                fontSize = 13.sp
                            )
                        },
                        modifier = Modifier
                            .fillMaxWidth(),
                        textStyle = TextStyle(color = Color.Black),
                        singleLine = true
                    )

                    OutlinedTextField(
                        value = selectedText,
                        onValueChange = { },
                        label = {
                            Text(
                                "Portas",
                                color = FechaduraColor
                            )
                        },
                        modifier = Modifier
                            .fillMaxWidth(),
                        enabled = false,
                        singleLine = true,
                        textStyle = TextStyle(color = Color.Black),
                        trailingIcon = {
                            IconButton(onClick = { showBottomSheet = true }) {
                                Icon(
                                    imageVector = Icons.Default.ArrowDropDown,
                                    contentDescription = "Abrir menu",
                                    tint = Color.Gray
                                )
                            }
                        },
                    )
                    val interactionSource = remember {
                        MutableInteractionSource()
                    }
                    Row(
                        modifier = Modifier
                            .clickable(
                                interactionSource = interactionSource,
                                indication = null,
                                role = Role.Switch,
                                onClick = {
                                    ativo = !ativo
                                }
                            )
                            .padding(top = 10.dp),
                        verticalAlignment = Alignment.CenterVertically
                    ) {
                        Text(
                            text = "Ativo",
                            fontWeight = FontWeight.Bold,
                            modifier = Modifier
                                .padding(end = 10.dp),
                            color = outlineLight
                        )

                        Switch(
                            checked = ativo,
                            onCheckedChange = { ativo = it },
                            thumbContent = if (ativo) {
                                {
                                    Icon(
                                        imageVector = Icons.Filled.Check,
                                        contentDescription = null,
                                        modifier = Modifier.size(SwitchDefaults.IconSize),
                                    )
                                }
                            } else {
                                null
                            },
                            colors = SwitchDefaults.colors(
                                checkedThumbColor = primaryLight,
                                checkedTrackColor = primaryContainerLight,
                                uncheckedThumbColor = onPrimaryLight,
                                uncheckedTrackColor = secondaryLight
                            )
                        )
                    }
                }
                Button(
                    onClick = {
                        navController.popBackStack()
                    },
                    Modifier
                        .fillMaxWidth()
                        .height(55.dp),
                    colors = ButtonDefaults.buttonColors(
                        containerColor = FechaduraColor
                    )
                ) {
                    Text(
                        text = "Cadastrar",
                        color = Color.White
                    )
                }
            }
        }
    }

    if (showBottomSheet) {
        ModalBottomSheet(
            containerColor = Color.White,
            onDismissRequest = { showBottomSheet = false },
            sheetState = sheetState
        ) {
            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(16.dp)
            ) {
                Text(
                    text = "Portas",
                    fontSize = 16.sp,
                    style = MaterialTheme.typography.titleLarge,
                    modifier = Modifier
                        .fillMaxWidth()
                        .wrapContentSize(Alignment.Center),
                )

                OutlinedTextField(
                    value = searchQuery,
                    onValueChange = { searchQuery = it },
                    label = { Text(text = "Pesquisar portas") },
                    modifier = Modifier.fillMaxWidth()
                )

                Spacer(modifier = Modifier.height(16.dp))

                if (selectedPortas.isNotEmpty()) {
                    LazyRow(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(vertical = 8.dp),
                        horizontalArrangement = Arrangement.spacedBy(8.dp),
                        contentPadding = PaddingValues(horizontal = 8.dp)
                    ) {
                        items(selectedPortas.toList()) { porta ->
                            Surface(
                                modifier = Modifier.padding(4.dp),
                                color = Color(0xFF4CAF50).copy(alpha = 0.1f),
                                shape = MaterialTheme.shapes.small,
                                onClick = {
                                    val updatedSelection = selectedPortas - porta
                                    selectedPortas = updatedSelection
                                    selectedText = if (selectedPortas.isEmpty()) {
                                        "Selecione as portas"
                                    } else {
                                        selectedPortas.joinToString(", ")
                                    }
                                }
                            ) {
                                Row(
                                    verticalAlignment = Alignment.CenterVertically,
                                    modifier = Modifier.padding(8.dp)
                                ) {
                                    Text(
                                        text = porta,
                                        color = Color(0xFF4CAF50),
                                        style = MaterialTheme.typography.bodyMedium
                                    )
                                    Spacer(modifier = Modifier.width(4.dp))
                                    IconButton(onClick = {
                                        val updatedSelection = selectedPortas - porta
                                        selectedPortas = updatedSelection
                                        selectedText = if (selectedPortas.isEmpty()) {
                                            "Selecione as portas"
                                        } else {
                                            selectedPortas.joinToString(", ")
                                        }
                                    }) {
                                        Icon(
                                            imageVector = Icons.Default.Close,
                                            contentDescription = "Remover porta",
                                            tint = Color(0xFF4CAF50)
                                        )
                                    }
                                }
                            }
                        }
                    }
                }

                Spacer(modifier = Modifier.height(8.dp))

                val filteredPortas = sampleDataPortas
                    .filter { it.descricao.contains(searchQuery, ignoreCase = true) }
                    .filterNot { it.descricao in selectedPortas }

                LazyColumn(
                    verticalArrangement = Arrangement.spacedBy(8.dp),
                    modifier = Modifier.fillMaxSize()
                ) {
                    items(filteredPortas) { porta ->
                        Column(
                            modifier = Modifier
                                .fillMaxWidth()
                                .clickable {
                                    val updatedSelection =
                                        if (selectedPortas.contains(porta.descricao)) {
                                            selectedPortas - porta.descricao
                                        } else {
                                            selectedPortas + porta.descricao
                                        }
                                    selectedPortas = updatedSelection
                                    selectedText = if (selectedPortas.isEmpty()) {
                                        "Selecione as portas"
                                    } else {
                                        selectedPortas.joinToString(", ")
                                    }
                                }
                                .padding(vertical = 8.dp)
                                .background(
                                    if (selectedPortas.contains(porta.descricao))
                                        Color(0x1F4CAF50)
                                    else Color.Transparent
                                )
                        ) {
                            Text(
                                text = porta.descricao,
                                modifier = Modifier
                                    .fillMaxWidth()
                                    .padding(16.dp),
                                style = MaterialTheme.typography.bodyLarge
                            )
                        }
                    }
                }

                Spacer(modifier = Modifier.height(16.dp))

                Button(onClick = {
                    scope.launch { sheetState.hide() }.invokeOnCompletion {
                        if (!sheetState.isVisible) {
                            showBottomSheet = false
                        }
                    }
                }) {
                    Text(text = "Confirmar")
                }
            }
        }
    }
}

