package com.br.fechadura.mobile.ui.screens.grupoPortas

import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.Edit
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.ModalBottomSheet
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import com.br.fechadura.mobile.ui.screens.FailScreen
import com.br.fechadura.mobile.ui.screens.LoadingScreen
import com.br.fechadura.mobile.viewModel.GrupoPortasViewModel
import com.br.vini.compose.api.ApiState
import androidx.compose.material3.TopAppBar
import androidx.compose.material3.TopAppBarDefaults
import androidx.compose.material3.rememberModalBottomSheetState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.graphics.Color.Companion.Black
import androidx.compose.ui.graphics.Color.Companion.Gray
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.sp
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.fechadura.mobile.ui.theme.outlineLight
import com.br.fechadura.mobile.ui.theme.surfaceContainerLight

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun VisualizarGrupoPorta(
    navController: NavController,
    id: String
) {
    val grupoPortaViewModel = viewModel<GrupoPortasViewModel>()
    val grupoState by grupoPortaViewModel.grupoPortaResponseBody

    val sheetState = rememberModalBottomSheetState()
    val scope = rememberCoroutineScope()
    var showBottomSheet by remember { mutableStateOf(false) }

    LaunchedEffect(id) {
        grupoPortaViewModel.getGrupoPortaById(id)
    }

    Scaffold(
        topBar = {
            TopAppBar(
                title = {
                    Text(grupoState.data?.nome ?: "Visualizar Grupo Porta")
                },
                navigationIcon = {
                    IconButton(onClick = { navController.popBackStack() }) { // Volta para a página anterior
                        Icon(
                            imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                            contentDescription = "Voltar",
                            tint = Color.White
                        )
                    }
                },
                actions = {
                    IconButton(onClick = { navController.navigate("editar-grupo-porta/${grupoState.data?._id}") }) { // Ação de edição
                        Icon(
                            imageVector = Icons.Default.Edit,
                            contentDescription = "Editar",
                            tint = Color.White
                        )
                    }
                },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = FechaduraColor,
                    actionIconContentColor = Gray,
                    navigationIconContentColor = Gray,
                    scrolledContainerColor = Gray,
                    titleContentColor = Color.White
                )
            )
        },
    ) { innerPadding ->
        Box(
            modifier = Modifier
                .fillMaxSize()
                .background(Color.White)
                .padding(innerPadding)
        ) {
            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(24.dp),
                verticalArrangement = Arrangement.Top,
                horizontalAlignment = Alignment.Start
            ) {

                when (grupoState) {
                    is ApiState.Created -> {}
                    is ApiState.Loading -> {
                        LoadingScreen()
                    }

                    is ApiState.Success -> {
                        grupoState.data?.let { grupoPorta ->
                            LazyColumn {
                                item {
                                    Column(
                                        modifier = Modifier
                                            .fillMaxWidth(),
                                        horizontalAlignment = Alignment.CenterHorizontally,
                                        verticalArrangement = Arrangement.Center
                                    ) {
                                        Text(
                                            text = grupoPorta.nome,
                                            fontSize = 20.sp,
                                            fontWeight = FontWeight.Bold
                                        )
                                        Text(
                                            text = grupoPorta.descricao,
                                            fontSize = 16.sp,
                                            textAlign = TextAlign.Center,
                                            color = outlineLight
                                        )
                                    }

                                    Spacer(modifier = Modifier.height(10.dp))

                                    Text(
                                        text = "Portas com acesso",
                                        color = FechaduraColor,
                                        fontSize = 16.sp,
                                        modifier = Modifier.fillMaxWidth(),
                                        textAlign = TextAlign.Center
                                    )

                                    if (grupoPorta.portas.isNotEmpty()) {
                                        grupoPorta.portas.forEach { porta ->
                                            Row(
                                                modifier = Modifier
                                                    .fillMaxWidth()
                                                    .height(76.dp)
                                                    .padding(top = 16.dp)
                                                    .background(
                                                        color = surfaceContainerLight,
                                                        shape = RoundedCornerShape(8.dp)
                                                    ),
                                                verticalAlignment = Alignment.CenterVertically
                                            ) {
                                                Text(
                                                    text = porta.descricao,
                                                    modifier = Modifier.padding(start = 20.dp)
                                                )
                                            }
                                        }
                                    }


                                    if (showBottomSheet) {
                                        ModalBottomSheet(
                                            onDismissRequest = {
                                                showBottomSheet = false
                                            },
                                            sheetState = sheetState
                                        ) {
                                            Column(
                                                modifier = Modifier
                                                    .fillMaxWidth()
                                                    .padding(16.dp)
                                            ) {
                                                Text(
                                                    text = "Portas",
                                                    fontSize = 20.sp,
                                                    textAlign = TextAlign.Center,
                                                    modifier = Modifier.fillMaxWidth()
                                                )
                                                if (grupoPorta.portas.isNotEmpty()) {
                                                    LazyColumn(
                                                        modifier = Modifier.fillMaxWidth()
                                                    ) {
                                                        items(grupoPorta.portas) { porta ->
                                                            Text(
                                                                text = porta.descricao,
                                                                modifier = Modifier
                                                                    .padding(vertical = 16.dp)
                                                                    .fillMaxWidth()
                                                            )
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        } ?: run {
                            Text(text = "Grupo não encontrado")
                        }
                    }

                    is ApiState.Error -> {
                        grupoState.message?.let { message ->
                            FailScreen(message)
                        }
                    }
                }
            }
        }
    }
}
