package com.br.fechadura.mobile.ui.screens.login

import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import com.br.fechadura.mobile.R
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.Color.Companion.Black
import androidx.compose.ui.graphics.Color.Companion.Gray
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import com.br.fechadura.mobile.viewModel.AuthViewModel
import androidx.navigation.compose.rememberNavController
import com.br.fechadura.mobile.ui.screens.LoadingScreen
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.vini.compose.api.ApiState

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun LoginScreen(navController: NavController) {

    val authViewModel = viewModel<AuthViewModel>()
    val loginState by authViewModel.loginResponseBody
    val autenticado by authViewModel.autenticado

    var email by remember { mutableStateOf("dev@gmail.com") }
    var senha by remember { mutableStateOf("123") }
    var passwordVisibility by remember { mutableStateOf(false) }

    Surface(
        color = Color.White,
        modifier = Modifier
            .fillMaxSize()
            .verticalScroll(rememberScrollState())

    ) {
        Column(
            modifier = Modifier
                .fillMaxSize()
                .padding(top = 100.dp),
            verticalArrangement = Arrangement.SpaceBetween,
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Column(horizontalAlignment = Alignment.CenterHorizontally) {
                Image(
                    painter = painterResource(id = R.drawable.fechadura_logo),
                    contentDescription = "Logo do ifro",
                    modifier = Modifier
                        .width(350.dp)
                        .height(344.dp)
                )
                Text(text = "Entre já em sua conta")
            }
            Column(
                modifier = Modifier.padding(bottom = 60.dp, start = 20.dp, end = 20.dp)
            ) {
                when (loginState) {
                    is ApiState.Created -> {}
                    is ApiState.Loading -> {}
                    is ApiState.Success -> {
                        println("LOGIN CHEGOU AQUI")
                        navController.navigate("inicio")
                    }
                    is ApiState.Error -> {
                        loginState.message?.let { message ->
                            Text(
                                message,
                                modifier = Modifier
                                    .fillMaxWidth()
                                    .padding(10.dp),
                                style = TextStyle(
                                    fontWeight = FontWeight.Bold,
                                    color = Color.Red
                                )
                            )
                        }
                    }
                }
                OutlinedTextField(
                    value = email,
                    onValueChange = { email = it },
                    label = {
                        Text(
                            "E-mail", style = TextStyle(
                                color = Black
                            )
                        )
                    },
                    modifier = Modifier.fillMaxWidth(),
                    colors = TextFieldDefaults.outlinedTextFieldColors(
                        focusedBorderColor = Gray,
                        unfocusedBorderColor = Black,
                        cursorColor = Black
                    ),
                    singleLine = true,
                    keyboardOptions = KeyboardOptions(imeAction = ImeAction.Done, keyboardType = KeyboardType.Email)
                )
                OutlinedTextField(
                    value = senha,
                    onValueChange = { senha = it },
                    label = {
                        Text(
                            "Senha",
                            style = TextStyle(
                                color = Black
                            )
                        )
                    },
                    visualTransformation = if (passwordVisibility) VisualTransformation.None else PasswordVisualTransformation(),
                    trailingIcon = {
                        IconButton(onClick = {
                            passwordVisibility = !passwordVisibility
                        }) {
                            val id = if (passwordVisibility) R.drawable.ic_visibility_off else R.drawable.ic_visibility_on
                            Icon(
                                painter = painterResource(id = id),
                                contentDescription = null
                            )
                        }
                    },
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(top = 10.dp),
                    colors = TextFieldDefaults.outlinedTextFieldColors(
                        focusedBorderColor = Gray,
                        unfocusedBorderColor = Black,
                        cursorColor = Black
                    ),
                    singleLine = true,
                    keyboardOptions = KeyboardOptions(imeAction = ImeAction.Done, keyboardType = KeyboardType.Password)
                )
                Button(
                    onClick = {
                        authViewModel.login(
                            email,
                            senha,
                            onComplete = {
                                println("LOGIN CHEGOU AQUI: oncomplete")
                                navController.navigate("inicio")
                            }
                        )
                    },
                    Modifier
                        .fillMaxWidth()
                        .padding(top = 30.dp)
                        .height(55.dp),
                    colors = ButtonDefaults.buttonColors(
                        containerColor = FechaduraColor
                    )
                ) {
                    Text(
                        text = "Entrar",
                        color = Color.White
                    )
                }
            }
        }
    }

    if(loginState is ApiState.Loading) {
        LoadingScreen()
    }
//
//    if(autenticado) {
//        navController.navigate("inicio")
//    }
}

@Preview
@Composable
private fun LoginScreenPreview() {
    LoginScreen(navController = rememberNavController())
}
