package com.br.fechadura.mobile.ui.screens.portas

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.ExperimentalMaterialApi
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.Check
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.RectangleShape
import androidx.compose.ui.layout.onGloballyPositioned
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.semantics.Role
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.fechadura.mobile.ui.theme.onPrimaryLight
import com.br.fechadura.mobile.ui.theme.outlineLight
import com.br.fechadura.mobile.ui.theme.primaryContainerLight
import com.br.fechadura.mobile.ui.theme.primaryLight
import com.br.fechadura.mobile.ui.theme.secondaryLight
import androidx.compose.material.ExposedDropdownMenuBox
import androidx.compose.material3.DropdownMenuItem

@OptIn(ExperimentalMaterial3Api::class, ExperimentalMaterialApi::class)
@Composable
fun CadastrarPorta(
    navController: NavController,
) {
    var descricao by remember { mutableStateOf("") }


    var ativo by remember { mutableStateOf(false) }

    // Lista de ambientes para o dropdown
    val sampleDataAmbientes = listOf("Bloco A", "Bloco B", "Bloco C", "Bloco D")
    var expanded by remember { mutableStateOf(false) }
    var selectedAmbiente by remember { mutableStateOf(sampleDataAmbientes[0]) }

    Scaffold(
        topBar = {
            TopAppBar(
                title = {
                    Text(descricao.takeIf { it.isNotEmpty() } ?: "Cadastrar Porta")
                },
                navigationIcon = {
                    IconButton(onClick = { navController.popBackStack() }) {
                        Icon(
                            imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                            contentDescription = "Voltar",
                            tint = Color.White
                        )
                    }
                },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = FechaduraColor,
                    actionIconContentColor = Color.Gray,
                    navigationIconContentColor = Color.Gray,
                    scrolledContainerColor = Color.Gray,
                    titleContentColor = Color.White
                )
            )
        },
    ) { innerPadding ->
        Box(
            modifier = Modifier
                .fillMaxSize()
                .background(Color.White)
                .padding(innerPadding)
        ) {
            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(20.dp),
                verticalArrangement = Arrangement.SpaceBetween
            ) {
                Column(
                    verticalArrangement = Arrangement.spacedBy(14.dp, Alignment.CenterVertically)
                ) {
                    OutlinedTextField(
                        value = descricao,
                        onValueChange = { descricao = it },
                        label = {
                            Text(
                                "Descrição",
                                color = FechaduraColor,
                                fontSize = 13.sp
                            )
                        },
                        modifier = Modifier
                            .fillMaxWidth(),
                        textStyle = TextStyle(color = Color.Black),
                        singleLine = true
                    )
                    
                    ExposedDropdownMenuBox(
                        expanded = expanded, 
                        onExpandedChange = { expanded = !expanded}
                    ) {
                    OutlinedTextField(
                        modifier = Modifier
                            .fillMaxWidth(),
                        readOnly = false,
                        value = selectedAmbiente,
                        onValueChange = {},
                        label = { Text(text = "Selecione o ambiente")},
                        trailingIcon = { ExposedDropdownMenuDefaults.TrailingIcon(expanded = expanded)},
                        colors = ExposedDropdownMenuDefaults.outlinedTextFieldColors()
                    )
                        ExposedDropdownMenu(
                            expanded = expanded,
                            onDismissRequest = { expanded = false}
                        ) {
                            sampleDataAmbientes.forEach { option ->
                                DropdownMenuItem(
                                    text = { Text(text = option)},
                                    onClick = {
                                        selectedAmbiente = option
                                        expanded = false
                                    },
                                    contentPadding = ExposedDropdownMenuDefaults.ItemContentPadding
                                )
                            }
                        }
                    }

                    Row(
                        modifier = Modifier
                            .clickable(
                                interactionSource = remember { MutableInteractionSource() },
                                indication = null,
                                role = Role.Switch,
                                onClick = {
                                    ativo = !ativo
                                }
                            )
                            .padding(top = 10.dp),
                        verticalAlignment = Alignment.CenterVertically
                    ) {
                        Text(
                            text = "Ativo",
                            fontWeight = FontWeight.Bold,
                            modifier = Modifier
                                .padding(end = 10.dp),
                            color = outlineLight
                        )

                        Switch(
                            checked = ativo,
                            onCheckedChange = { ativo = it },
                            thumbContent = if (ativo) {
                                {
                                    Icon(
                                        imageVector = Icons.Filled.Check,
                                        contentDescription = null,
                                        modifier = Modifier.size(SwitchDefaults.IconSize),
                                    )
                                }
                            } else {
                                null
                            },
                            colors = SwitchDefaults.colors(
                                checkedThumbColor = primaryLight,
                                checkedTrackColor = primaryContainerLight,
                                uncheckedThumbColor = onPrimaryLight,
                                uncheckedTrackColor = secondaryLight
                            )
                        )
                    }
                }
                Button(
                    onClick = {
                        navController.popBackStack()
                    },
                    Modifier
                        .fillMaxWidth()
                        .height(55.dp),
                    colors = ButtonDefaults.buttonColors(
                        containerColor = FechaduraColor
                    )
                ) {
                    Text(
                        text = "Cadastrar",
                        color = Color.White
                    )
                }
            }
        }
    }
}
