package com.br.fechadura.mobile.ui.screens.usuario

import android.util.Log
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.LazyRow
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.automirrored.filled.ArrowBack
import androidx.compose.material.icons.filled.ArrowDropDown
import androidx.compose.material.icons.filled.Check
import androidx.compose.material.icons.filled.Close
import androidx.compose.material.icons.filled.Person
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.semantics.Role
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.NavController
import androidx.navigation.compose.rememberNavController
import com.br.fechadura.mobile.sampledata.sampleDataDoors
import com.br.fechadura.mobile.sampledata.sampleDataGroupUser
import com.br.fechadura.mobile.ui.components.CaixaDialogo
import com.br.fechadura.mobile.ui.components.CaixaLoading
import com.br.fechadura.mobile.ui.screens.LoadingScreen
import com.br.fechadura.mobile.ui.theme.FechaduraColor
import com.br.fechadura.mobile.ui.theme.onPrimaryLight
import com.br.fechadura.mobile.ui.theme.outlineLight
import com.br.fechadura.mobile.ui.theme.primaryContainerLight
import com.br.fechadura.mobile.ui.theme.primaryLight
import com.br.fechadura.mobile.ui.theme.secondaryLight
import com.br.fechadura.mobile.viewModel.GrupoUsuariosViewModel
import com.br.fechadura.mobile.viewModel.PortasViewModel
import com.br.fechadura.mobile.viewModel.UsuariosViewModel
import com.br.vini.compose.api.ApiState
import kotlinx.coroutines.launch

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun CadastrarUsuario(navController: NavController) {

    var link_foto by remember { mutableStateOf("") }
    var nome by remember { mutableStateOf("") }
    var email by remember { mutableStateOf("") }
    var ativo by remember { mutableStateOf(false) }
    var codigoAcesso by remember { mutableStateOf("") }

    val postViewModel = viewModel<UsuariosViewModel>()
    val postState by postViewModel.usuarioResponsePost

    var selectedGrupo by remember { mutableStateOf(setOf<String>()) }
    var selectedTextGrupo by remember { mutableStateOf("Selecione os grupos") }
    var searchQueryGrupo by remember { mutableStateOf("") }

    var selectedPortas by remember { mutableStateOf(setOf<String>()) }
    var selectedTextPortas by remember { mutableStateOf("Selecione as portas") }
    var searchQueryPortas by remember { mutableStateOf("") }

    val sheetState = rememberModalBottomSheetState()
    val scope = rememberCoroutineScope()

    var showBottomSheetPortas by remember { mutableStateOf(false) }
    var showBottomSheetGrupo by remember { mutableStateOf(false) }

    val portaViewModel: PortasViewModel = viewModel()
    val portasState by portaViewModel.allPortas

    val grupoUsuariosViewModel: GrupoUsuariosViewModel = viewModel()
    val grupoState by grupoUsuariosViewModel.allGrupoUsuarios

    val snackbarHostState = remember { SnackbarHostState() }
    Scaffold(
        snackbarHost = { SnackbarHost(hostState = snackbarHostState) },
        topBar = {
            TopAppBar(
                title = { Text("Cadastrar Usuário", color = Color.White) },
                colors = TopAppBarDefaults.topAppBarColors(
                    containerColor = FechaduraColor
                ),
                navigationIcon = {
                    IconButton(onClick = { navController.popBackStack() }) {
                        Icon(
                            imageVector = Icons.AutoMirrored.Filled.ArrowBack,
                            contentDescription = "Voltar para início",
                            tint = Color.White
                        )
                    }
                }
            )
        },
    ) { innerPadding ->
        Box(
            modifier = Modifier
                .fillMaxSize()
                .background(Color.White)
                .padding(innerPadding)
        ) {

            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(20.dp),
                verticalArrangement = Arrangement.SpaceBetween
            ) {
                Column(
                    horizontalAlignment = Alignment.CenterHorizontally,
                    verticalArrangement = Arrangement.spacedBy(
                        14.dp,
                        Alignment.CenterVertically
                    )
                ) {
                    Box(
                        modifier = Modifier
                            .size(100.dp)
                            .clip(CircleShape)
                            .background(Color.Gray),
                        contentAlignment = Alignment.Center,
                    ) {
                        Icon(
                            imageVector = Icons.Default.Person,
                            contentDescription = "User Avatar",
                            modifier = Modifier.size(80.dp),
                            tint = Color.Black
                        )
                    }
                    OutlinedTextField(
                        value = nome,
                        onValueChange = { nome = it },
                        label = {
                            Text(
                                "Nome",
                                color = FechaduraColor,
                                fontSize = 13.sp
                            )
                        },
                        modifier = Modifier
                            .fillMaxWidth(),
                        textStyle = TextStyle(color = Color.Black),
                        singleLine = true,
                        isError = postState is ApiState.Error
                    )

                    OutlinedTextField(
                        value = email,
                        onValueChange = { email = it },
                        label = {
                            Text(
                                "E-mail",
                                color = FechaduraColor,
                                fontSize = 13.sp,
                            )
                        },
                        modifier = Modifier
                            .fillMaxWidth(),
                        textStyle = TextStyle(color = Color.Black),
                        singleLine = true,
                        isError = postState is ApiState.Error
                    )

                    OutlinedTextField(
                        value = selectedTextGrupo,
                        onValueChange = { },
                        label = {
                            Text(
                                "Grupo de Usuários",
                                color = FechaduraColor
                            )
                        },
                        modifier = Modifier
                            .fillMaxWidth(),
                        enabled = false,
                        singleLine = true,
                        isError = postState is ApiState.Error,
                        textStyle = TextStyle(color = Color.Black),
                        trailingIcon = {
                            IconButton(onClick = { showBottomSheetGrupo = true }) {
                                Icon(
                                    imageVector = Icons.Default.ArrowDropDown,
                                    contentDescription = "Abrir menu",
                                    tint = Color.Gray
                                )
                            }
                        },
                    )

                    OutlinedTextField(
                        value = selectedTextPortas,
                        onValueChange = { },
                        label = {
                            Text(
                                "Portas",
                                color = FechaduraColor
                            )
                        },
                        modifier = Modifier
                            .fillMaxWidth(),
                        enabled = false,
                        singleLine = true,
                        isError = postState is ApiState.Error,
                        textStyle = TextStyle(color = Color.Black),
                        trailingIcon = {
                            IconButton(onClick = {
                                showBottomSheetPortas = true
                            }) {
                                Icon(
                                    imageVector = Icons.Default.ArrowDropDown,
                                    contentDescription = "Abrir menu",
                                    tint = Color.Gray
                                )
                            }
                        },
                    )
                    val interactionSource = remember {
                        MutableInteractionSource()
                    }
                    Row(
                        modifier = Modifier
                            .clickable(
                                interactionSource = interactionSource,
                                indication = null,
                                role = Role.Switch,
                                onClick = {
                                    ativo = !ativo
                                }
                            )
                            .fillMaxWidth()
                            .padding(top = 10.dp),
                        verticalAlignment = Alignment.CenterVertically,
                        horizontalArrangement = Arrangement.SpaceBetween
                    ) {
                        Row(
                            verticalAlignment = Alignment.CenterVertically
                        ) {
                            Text(
                                text = "Ativo",
                                fontWeight = FontWeight.Bold,
                                modifier = Modifier
                                    .padding(end = 10.dp),
                                color = outlineLight
                            )

                            Switch(
                                checked = ativo,
                                onCheckedChange = { ativo = it },
                                thumbContent = if (ativo) {
                                    {
                                        Icon(
                                            imageVector = Icons.Filled.Check,
                                            contentDescription = null,
                                            modifier = Modifier.size(SwitchDefaults.IconSize),
                                        )
                                    }
                                } else {
                                    null
                                },
                                colors = SwitchDefaults.colors(
                                    checkedThumbColor = primaryLight,
                                    checkedTrackColor = primaryContainerLight,
                                    uncheckedThumbColor = onPrimaryLight,
                                    uncheckedTrackColor = secondaryLight
                                )
                            )
                        }
                        val maxLength = 10
                        val isError = codigoAcesso.length > maxLength
                        OutlinedTextField(
                            value = codigoAcesso,
                            onValueChange = {
                                if (it.length <= maxLength) {
                                    codigoAcesso = it
                                }
                            },
                            label = {
                                Text(
                                    "Código",
                                    color = FechaduraColor,
                                    fontSize = 13.sp
                                )
                            },
                            modifier = Modifier.width(150.dp),
                            textStyle = TextStyle(color = Color.Black),
                            singleLine = true,
                            isError = postState is ApiState.Error
                        )


                    }
                }
                Button(
                    onClick = {
                        postViewModel.postUsuario(
                            link_foto,
                            nome,
                            email,
                            ativo,
                            codigoAcesso,
                            selectedGrupo.toList(),
                            selectedPortas.toList(),
                        )
                    },
                    Modifier
                        .fillMaxWidth()
                        .height(55.dp),
                    colors = ButtonDefaults.buttonColors(
                        containerColor = FechaduraColor
                    )
                ) {
                    Text(
                        text = "Cadastrar",
                        color = Color.White
                    )
                }
                LaunchedEffect(postState) {
                    when (postState) {
                        is ApiState.Created -> {
                            println("Chegou aqui: Created")
                        }

                        is ApiState.Loading -> {
                            println("Chegou aqui: Loading")
                        }

                        is ApiState.Success -> {
                            println("Chegou aqui: Success")
                            postState.data?.let { responseData ->
                                Log.i("API_RESPONSE", responseData.nome)
                            }
                            scope.launch {
                                snackbarHostState
                                    .showSnackbar(
                                        message = "Usuário cadastrado com sucesso",
                                        duration = SnackbarDuration.Short
                                    )
                            }

                            navController.popBackStack()
                        }

                        is ApiState.Error -> {
                            postState.message?.let { message ->
                                scope.launch {
                                    snackbarHostState
                                        .showSnackbar(
                                            message = message,
                                            duration = SnackbarDuration.Short
                                        )
                                }
                            }
                        }
                    }
                }
            }
        }
    }


    // Portas
    if (showBottomSheetPortas) {
        ModalBottomSheet(
            containerColor = Color.White,
            onDismissRequest = { showBottomSheetPortas = false },
            sheetState = sheetState
        ) {
            when (portasState) {
                is ApiState.Error -> {
                    // Exibir uma mensagem de erro ou uma tela de falha
                    Text("Erro ao carregar as portas.")
                }

                is ApiState.Created -> {}
                is ApiState.Loading -> {
                    // Exibir uma tela de carregamento
                    LoadingScreen()
                }

                is ApiState.Success -> {
                    portasState.data?.let { responseData ->
                        Column(
                            modifier = Modifier
                                .fillMaxSize()
                                .padding(16.dp)
                        ) {
                            Text(
                                text = "Portas",
                                fontSize = 16.sp,
                                style = MaterialTheme.typography.titleLarge,
                                modifier = Modifier
                                    .fillMaxWidth()
                                    .wrapContentSize(Alignment.Center),
                            )

                            OutlinedTextField(
                                value = searchQueryPortas,
                                onValueChange = { searchQueryPortas = it },
                                label = { Text(text = "Pesquisar portas") },
                                modifier = Modifier.fillMaxWidth()
                            )

                            Spacer(modifier = Modifier.height(16.dp))

                            if (selectedPortas.isNotEmpty()) {
                                LazyRow(
                                    modifier = Modifier
                                        .fillMaxWidth()
                                        .padding(vertical = 8.dp),
                                    horizontalArrangement = Arrangement.spacedBy(8.dp),
                                    contentPadding = PaddingValues(horizontal = 8.dp)
                                ) {
                                    items(selectedPortas.toList()) { portaId ->
                                        val porta = responseData.data.find { it._id == portaId }
                                        porta?.let {
                                            Surface(
                                                modifier = Modifier.padding(4.dp),
                                                color = Color(0xFF4CAF50).copy(alpha = 0.1f),
                                                shape = MaterialTheme.shapes.small,
                                                onClick = {
                                                    val updatedSelection = selectedPortas - portaId
                                                    selectedPortas = updatedSelection
                                                    selectedTextPortas =
                                                        if (selectedPortas.isEmpty()) {
                                                            "Selecione as portas"
                                                        } else {
                                                            // Atualizar o texto para mostrar as descrições
                                                            selectedPortas
                                                                .mapNotNull { id -> responseData.data.find { it._id == id }?.descricao }
                                                                .joinToString(", ")
                                                        }
                                                }
                                            ) {
                                                Row(
                                                    verticalAlignment = Alignment.CenterVertically,
                                                    modifier = Modifier.padding(8.dp)
                                                ) {
                                                    Text(
                                                        text = porta.descricao,
                                                        color = Color(0xFF4CAF50),
                                                        style = MaterialTheme.typography.bodyMedium
                                                    )
                                                    Spacer(modifier = Modifier.width(4.dp))
                                                    IconButton(onClick = {
                                                        val updatedSelection =
                                                            selectedPortas - portaId
                                                        selectedPortas = updatedSelection
                                                        selectedTextPortas =
                                                            if (selectedPortas.isEmpty()) {
                                                                "Selecione as portas"
                                                            } else {
                                                                // Atualizar o texto para mostrar as descrições
                                                                selectedPortas
                                                                    .mapNotNull { id -> responseData.data.find { it._id == id }?.descricao }
                                                                    .joinToString(", ")
                                                            }
                                                    }) {
                                                        Icon(
                                                            imageVector = Icons.Default.Close,
                                                            contentDescription = "Remover porta",
                                                            tint = Color(0xFF4CAF50)
                                                        )
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }

                            Spacer(modifier = Modifier.height(8.dp))

                            val filteredPortas = responseData.data
                                .filter {
                                    it.descricao.contains(searchQueryPortas, ignoreCase = true)
                                }
                                .filterNot { it._id in selectedPortas }

                            LazyColumn(
                                verticalArrangement = Arrangement.spacedBy(8.dp),
                                modifier = Modifier.fillMaxSize()
                            ) {
                                items(filteredPortas) { porta ->
                                    Column(
                                        modifier = Modifier
                                            .fillMaxWidth()
                                            .clickable {
                                                val updatedSelection =
                                                    if (selectedPortas.contains(porta._id)) {
                                                        selectedPortas - porta._id
                                                    } else {
                                                        selectedPortas + porta._id
                                                    }
                                                selectedPortas = updatedSelection
                                                selectedTextPortas = if (selectedPortas.isEmpty()) {
                                                    "Selecione as portas"
                                                } else {
                                                    // Atualizar o texto para mostrar as descrições
                                                    selectedPortas
                                                        .mapNotNull { id -> responseData.data.find { it._id == id }?.descricao }
                                                        .joinToString(", ")
                                                }
                                            }
                                            .padding(vertical = 8.dp)
                                            .background(
                                                if (selectedPortas.contains(porta._id))
                                                    Color(0x1F4CAF50)
                                                else Color.Transparent
                                            )
                                    ) {
                                        Column {
                                            Text(
                                                text = porta.descricao,
                                                modifier = Modifier
                                                    .fillMaxWidth()
                                                    .padding(16.dp),
                                                style = MaterialTheme.typography.bodyLarge
                                            )
                                            Text(
                                                text = porta.ambiente ?: "",
                                                modifier = Modifier
                                                    .fillMaxWidth()
                                                    .padding(start = 16.dp)
                                                    .padding(top = 4.dp),
                                                style = MaterialTheme.typography.bodyMedium,
                                                color = Color.Gray
                                            )
                                        }
                                    }
                                }
                            }

                            Spacer(modifier = Modifier.height(16.dp))

                            Button(onClick = {
                                // Atualizar a descrição no TextField ao fechar o BottomSheet
                                selectedTextPortas = selectedPortas
                                    .mapNotNull { id -> responseData.data.find { it._id == id }?.descricao }
                                    .joinToString(", ")
                                scope.launch { sheetState.hide() }.invokeOnCompletion {
                                    if (!sheetState.isVisible) {
                                        showBottomSheetPortas = false
                                    }
                                }
                            }) {
                                Text(text = "Confirmar")
                            }
                        }
                    }
                }
            }
        }
    }


    // Grupo de Usuários
    if (showBottomSheetGrupo) {
        ModalBottomSheet(
            containerColor = Color.White,
            onDismissRequest = { showBottomSheetGrupo = false },
            sheetState = sheetState
        ) {
            when (grupoState) {
                is ApiState.Error -> {
                    // Trate o erro aqui, se necessário
                }

                is ApiState.Loading -> {
                    // Exiba a tela de carregamento
                }

                is ApiState.Created -> {
                    // Trate a criação, se necessário
                }

                is ApiState.Success -> {
                    grupoState.data?.let { responseData ->
                        Column(
                            modifier = Modifier
                                .fillMaxSize()
                                .padding(16.dp)
                        ) {
                            Text(
                                text = "Grupos de Usuários",
                                fontSize = 16.sp,
                                style = MaterialTheme.typography.titleLarge,
                                modifier = Modifier
                                    .fillMaxWidth()
                                    .wrapContentSize(Alignment.Center),
                            )

                            OutlinedTextField(
                                value = searchQueryGrupo,
                                onValueChange = { searchQueryGrupo = it },
                                label = { Text(text = "Pesquisar grupos") },
                                modifier = Modifier.fillMaxWidth(),
                                singleLine = true
                            )

                            Spacer(modifier = Modifier.height(16.dp))

                            if (selectedGrupo.isNotEmpty()) {
                                LazyRow(
                                    modifier = Modifier
                                        .fillMaxWidth()
                                        .padding(vertical = 8.dp),
                                    horizontalArrangement = Arrangement.spacedBy(8.dp),
                                    contentPadding = PaddingValues(horizontal = 8.dp)
                                ) {
                                    items(selectedGrupo.toList()) { grupoId ->
                                        val grupoIdString = grupoId.toString()
                                        val grupo =
                                            responseData.data.find { it._id == grupoIdString }
                                        grupo?.let {
                                            Surface(
                                                modifier = Modifier.padding(4.dp),
                                                color = Color(0xFF4CAF50).copy(alpha = 0.1f),
                                                shape = MaterialTheme.shapes.small,
                                                onClick = {
                                                    val updatedSelection = selectedGrupo - grupoId
                                                    selectedGrupo = updatedSelection
                                                    selectedTextGrupo =
                                                        if (selectedGrupo.isEmpty()) {
                                                            "Selecione os grupos"
                                                        } else {
                                                            selectedGrupo.joinToString(", ") { id ->
                                                                responseData.data.find { it._id == id }?.nome
                                                                    ?: id
                                                            }
                                                        }
                                                }
                                            ) {
                                                Row(
                                                    verticalAlignment = Alignment.CenterVertically,
                                                    modifier = Modifier.padding(8.dp)
                                                ) {
                                                    Text(
                                                        text = grupo.nome,
                                                        color = Color(0xFF4CAF50),
                                                        style = MaterialTheme.typography.bodyMedium
                                                    )
                                                    Spacer(modifier = Modifier.width(4.dp))
                                                    IconButton(onClick = {
                                                        val updatedSelection =
                                                            selectedGrupo - grupoId
                                                        selectedGrupo = updatedSelection
                                                        selectedTextGrupo =
                                                            if (selectedGrupo.isEmpty()) {
                                                                "Selecione os grupos"
                                                            } else {
                                                                selectedGrupo.joinToString(", ") { id ->
                                                                    responseData.data.find { it._id == id }?.nome
                                                                        ?: id
                                                                }
                                                            }
                                                    }) {
                                                        Icon(
                                                            imageVector = Icons.Default.Close,
                                                            contentDescription = "Remover grupo",
                                                            tint = Color(0xFF4CAF50)
                                                        )
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            }

                            Spacer(modifier = Modifier.height(8.dp))

                            val filteredGrupos = responseData.data
                                .filter { it.nome.contains(searchQueryGrupo, ignoreCase = true) }
                                .filterNot { it._id in selectedGrupo }

                            LazyColumn(
                                verticalArrangement = Arrangement.spacedBy(8.dp),
                                modifier = Modifier.fillMaxSize()
                            ) {
                                items(filteredGrupos) { grupo ->
                                    Column(
                                        modifier = Modifier
                                            .fillMaxWidth()
                                            .clickable {
                                                val updatedSelection =
                                                    if (selectedGrupo.contains(grupo._id)) {
                                                        selectedGrupo - grupo._id
                                                    } else {
                                                        selectedGrupo + grupo._id
                                                    }
                                                selectedGrupo = updatedSelection
                                                selectedTextGrupo = if (selectedGrupo.isEmpty()) {
                                                    "Selecione os grupos"
                                                } else {
                                                    selectedGrupo.joinToString(", ") { id ->
                                                        responseData.data.find { it._id == id }?.nome
                                                            ?: id
                                                    }
                                                }
                                            }
                                            .padding(vertical = 8.dp)
                                            .background(
                                                if (selectedGrupo.contains(grupo._id))
                                                    Color(0x1F4CAF50)
                                                else Color.Transparent
                                            )
                                    ) {
                                        Text(
                                            text = grupo.nome,
                                            modifier = Modifier
                                                .fillMaxWidth()
                                                .padding(16.dp),
                                            style = MaterialTheme.typography.bodyLarge
                                        )
                                    }
                                }
                            }

                            Spacer(modifier = Modifier.height(16.dp))

                            Button(onClick = {
                                scope.launch { sheetState.hide() }.invokeOnCompletion {
                                    if (!sheetState.isVisible) {
                                        showBottomSheetGrupo = false
                                    }
                                }
                            }) {
                                Text(text = "Confirmar")
                            }
                        }
                    }
                }
            }
        }
    }
    if (postState is ApiState.Loading) {
        CaixaLoading()
    }

    LaunchedEffect(Unit) {
        grupoUsuariosViewModel.getAllGrupoUsuarios()

    }

    LaunchedEffect(Unit) {
        portaViewModel.getAllPortas()
    }
}


@Preview(showBackground = true)
@Composable
private fun CadastrarUsuarioPreview() {
    CadastrarUsuario(navController = rememberNavController())
}
