package com.br.fechadura.mobile.viewModel

import android.app.Application
import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.AndroidViewModel
import com.br.fechadura.mobile.datastore.AppDataStore
import com.br.fechadura.mobile.datastore.PerfilLocal
import com.br.vini.compose.api.ApiRepository
import androidx.compose.runtime.State
import androidx.lifecycle.viewModelScope
import com.br.fechadura.mobile.datastore.AppDataStoreKeys
import kotlinx.coroutines.flow.first
import kotlinx.coroutines.launch
import kotlinx.coroutines.runBlocking

open class MainViewModel(
    application: Application
) : AndroidViewModel(application) {
    protected val apiRepository = ApiRepository()
    protected val appDataStore = AppDataStore(application.applicationContext)

    protected var _autenticado = mutableStateOf(false)
    var autenticado: State<Boolean> = _autenticado

    protected var _perfilLocal = mutableStateOf(PerfilLocal())
    var perfilLocal: State<PerfilLocal> = _perfilLocal

    init {
        loadLocalProfile()
    }

    protected fun setAutenticado(autenticado: Boolean) {
        _autenticado.value = autenticado
    }

    private fun loadLocalProfile() {
        viewModelScope.launch {
            runBlocking {
                _autenticado.value = appDataStore.getBoolean(AppDataStoreKeys.AUTENTICADO).first()
                _perfilLocal.value.nome = appDataStore.getString(AppDataStoreKeys.NOME).first()
                _perfilLocal.value.email = appDataStore.getString(AppDataStoreKeys.EMAIL).first()
                _perfilLocal.value.link_foto = appDataStore.getString(AppDataStoreKeys.LINK_FOTO).first()
            }
        }
    }
}