package com.br.fechadura.mobile.viewModel


import android.app.Application
import androidx.compose.runtime.Composable
import androidx.compose.runtime.State
import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.AndroidViewModel
import androidx.lifecycle.viewModelScope
import com.br.fechadura.mobile.api.request.UsuarioRequestBody
import com.br.fechadura.mobile.api.response.PortasResponseBody
import com.br.fechadura.mobile.api.response.UsuarioPostResponseBody
import com.br.fechadura.mobile.api.response.UsuarioResponseBody
import com.br.fechadura.mobile.api.response.UsuariosResponseBody
import com.br.vini.compose.api.ApiRepository
import com.br.vini.compose.api.ApiState
import kotlinx.coroutines.launch

class UsuariosViewModel(
    private val application: Application
) : AndroidViewModel(application) {
    private val apiRepository = ApiRepository()

    private val _allUsuarios = mutableStateOf<ApiState<UsuariosResponseBody>>(ApiState.Created())
    val allUsuarios: State<ApiState<UsuariosResponseBody>> = _allUsuarios

    fun getAllUsuarios() {
        viewModelScope.launch {
            _allUsuarios.value = ApiState.Loading()
            _allUsuarios.value = apiRepository.getAllUsuarios()
        }
    }

    private val _usuariosResponseBody = mutableStateOf<ApiState<UsuariosResponseBody>>(ApiState.Created())
    val usuariosResponseBody: State<ApiState<UsuariosResponseBody>> = _usuariosResponseBody

    fun getUsuarios() {
        viewModelScope.launch {
            _usuariosResponseBody.value = ApiState.Loading()
            _usuariosResponseBody.value = apiRepository.getUsuarios()

        }
    }

    private val _usuarioResponse = mutableStateOf<ApiState<UsuarioResponseBody>>(ApiState.Created())
    val usuarioResponse: State<ApiState<UsuarioResponseBody>> = _usuarioResponse

    fun getUsuarioById(id: String) {
        viewModelScope.launch {
            _usuarioResponse.value = ApiState.Loading()
            _usuarioResponse.value = apiRepository.getUsuarioById(id)

        }
    }

    private val _usuarioResponsePost = mutableStateOf<ApiState<UsuarioPostResponseBody>>(ApiState.Created())
    val usuarioResponsePost: State<ApiState<UsuarioPostResponseBody>> = _usuarioResponsePost

    fun postUsuario(
        link_foto: String? = null,
        nome: String,
        email: String,
        ativo: Boolean = false,
        codigo_acesso: String,
        grupoUsuarios: List<Any> = emptyList(),
        portas: List<Any> = emptyList()
    ) {
        if(nome.isBlank()) {
            _usuarioResponsePost.value = ApiState.Error("Informe o nome do usuário")
            return
        }

        if(email.isBlank()) {
            _usuarioResponsePost.value = ApiState.Error("Informe o e-mail do usuário")
            return
        }

        val emailRegex = Regex("^[A-Za-z0-9+_.-]+@[A-Za-z0-9.-]+$")
        if (!email.matches(emailRegex)) {
            _usuarioResponsePost.value = ApiState.Error("E-mail inválido")
            return
        }

        if(codigo_acesso.length > 8 || codigo_acesso.length < 8) {
            _usuarioResponsePost.value = ApiState.Error("O codigo de acesso deve ter 8 digítos")
            return
        }

        val requestBody = UsuarioRequestBody()

        requestBody.nome = nome
        requestBody.email = email
        requestBody.ativo = ativo
        requestBody.codigo_acesso = codigo_acesso

        requestBody.grupoUsuarios = grupoUsuarios
        requestBody.portas = portas

        viewModelScope.launch {
            _usuarioResponsePost.value = ApiState.Loading()
            _usuarioResponsePost.value = apiRepository.postUsuario(requestBody)
        }

    }

    fun clearApiState() {
        _usuarioResponsePost.value = ApiState.Created()
    }
}